"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import shared_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class ReadReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class Options(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class UUIDOption(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            STRUCTURED_FIELD_NUMBER: builtins.int
            STRING_FIELD_NUMBER: builtins.int
            @property
            def structured(self) -> shared_pb2.Empty: ...
            @property
            def string(self) -> shared_pb2.Empty: ...
            def __init__(
                self,
                *,
                structured: shared_pb2.Empty | None = ...,
                string: shared_pb2.Empty | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing_extensions.Literal["content", b"content", "string", b"string", "structured", b"structured"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing_extensions.Literal["content", b"content", "string", b"string", "structured", b"structured"]) -> None: ...
            def WhichOneof(self, oneof_group: typing_extensions.Literal["content", b"content"]) -> typing_extensions.Literal["structured", "string"] | None: ...

        STREAM_IDENTIFIER_FIELD_NUMBER: builtins.int
        ALL_FIELD_NUMBER: builtins.int
        GROUP_NAME_FIELD_NUMBER: builtins.int
        BUFFER_SIZE_FIELD_NUMBER: builtins.int
        UUID_OPTION_FIELD_NUMBER: builtins.int
        @property
        def stream_identifier(self) -> shared_pb2.StreamIdentifier: ...
        @property
        def all(self) -> shared_pb2.Empty: ...
        group_name: builtins.str
        buffer_size: builtins.int
        @property
        def uuid_option(self) -> global___ReadReq.Options.UUIDOption: ...
        def __init__(
            self,
            *,
            stream_identifier: shared_pb2.StreamIdentifier | None = ...,
            all: shared_pb2.Empty | None = ...,
            group_name: builtins.str = ...,
            buffer_size: builtins.int = ...,
            uuid_option: global___ReadReq.Options.UUIDOption | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["all", b"all", "stream_identifier", b"stream_identifier", "stream_option", b"stream_option", "uuid_option", b"uuid_option"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["all", b"all", "buffer_size", b"buffer_size", "group_name", b"group_name", "stream_identifier", b"stream_identifier", "stream_option", b"stream_option", "uuid_option", b"uuid_option"]) -> None: ...
        def WhichOneof(self, oneof_group: typing_extensions.Literal["stream_option", b"stream_option"]) -> typing_extensions.Literal["stream_identifier", "all"] | None: ...

    class Ack(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ID_FIELD_NUMBER: builtins.int
        IDS_FIELD_NUMBER: builtins.int
        id: builtins.bytes
        @property
        def ids(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[shared_pb2.UUID]: ...
        def __init__(
            self,
            *,
            id: builtins.bytes = ...,
            ids: collections.abc.Iterable[shared_pb2.UUID] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "ids", b"ids"]) -> None: ...

    class Nack(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _Action:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _ActionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ReadReq.Nack._Action.ValueType], builtins.type):  # noqa: F821
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            Unknown: ReadReq.Nack._Action.ValueType  # 0
            Park: ReadReq.Nack._Action.ValueType  # 1
            Retry: ReadReq.Nack._Action.ValueType  # 2
            Skip: ReadReq.Nack._Action.ValueType  # 3
            Stop: ReadReq.Nack._Action.ValueType  # 4

        class Action(_Action, metaclass=_ActionEnumTypeWrapper): ...
        Unknown: ReadReq.Nack.Action.ValueType  # 0
        Park: ReadReq.Nack.Action.ValueType  # 1
        Retry: ReadReq.Nack.Action.ValueType  # 2
        Skip: ReadReq.Nack.Action.ValueType  # 3
        Stop: ReadReq.Nack.Action.ValueType  # 4

        ID_FIELD_NUMBER: builtins.int
        IDS_FIELD_NUMBER: builtins.int
        ACTION_FIELD_NUMBER: builtins.int
        REASON_FIELD_NUMBER: builtins.int
        id: builtins.bytes
        @property
        def ids(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[shared_pb2.UUID]: ...
        action: global___ReadReq.Nack.Action.ValueType
        reason: builtins.str
        def __init__(
            self,
            *,
            id: builtins.bytes = ...,
            ids: collections.abc.Iterable[shared_pb2.UUID] | None = ...,
            action: global___ReadReq.Nack.Action.ValueType = ...,
            reason: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "id", b"id", "ids", b"ids", "reason", b"reason"]) -> None: ...

    OPTIONS_FIELD_NUMBER: builtins.int
    ACK_FIELD_NUMBER: builtins.int
    NACK_FIELD_NUMBER: builtins.int
    @property
    def options(self) -> global___ReadReq.Options: ...
    @property
    def ack(self) -> global___ReadReq.Ack: ...
    @property
    def nack(self) -> global___ReadReq.Nack: ...
    def __init__(
        self,
        *,
        options: global___ReadReq.Options | None = ...,
        ack: global___ReadReq.Ack | None = ...,
        nack: global___ReadReq.Nack | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["ack", b"ack", "content", b"content", "nack", b"nack", "options", b"options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ack", b"ack", "content", b"content", "nack", b"nack", "options", b"options"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["content", b"content"]) -> typing_extensions.Literal["options", "ack", "nack"] | None: ...

global___ReadReq = ReadReq

class ReadResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class ReadEvent(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class RecordedEvent(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            class MetadataEntry(google.protobuf.message.Message):
                DESCRIPTOR: google.protobuf.descriptor.Descriptor

                KEY_FIELD_NUMBER: builtins.int
                VALUE_FIELD_NUMBER: builtins.int
                key: builtins.str
                value: builtins.str
                def __init__(
                    self,
                    *,
                    key: builtins.str = ...,
                    value: builtins.str = ...,
                ) -> None: ...
                def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

            ID_FIELD_NUMBER: builtins.int
            STREAM_IDENTIFIER_FIELD_NUMBER: builtins.int
            STREAM_REVISION_FIELD_NUMBER: builtins.int
            PREPARE_POSITION_FIELD_NUMBER: builtins.int
            COMMIT_POSITION_FIELD_NUMBER: builtins.int
            METADATA_FIELD_NUMBER: builtins.int
            CUSTOM_METADATA_FIELD_NUMBER: builtins.int
            DATA_FIELD_NUMBER: builtins.int
            @property
            def id(self) -> shared_pb2.UUID: ...
            @property
            def stream_identifier(self) -> shared_pb2.StreamIdentifier: ...
            stream_revision: builtins.int
            prepare_position: builtins.int
            commit_position: builtins.int
            @property
            def metadata(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
            custom_metadata: builtins.bytes
            data: builtins.bytes
            def __init__(
                self,
                *,
                id: shared_pb2.UUID | None = ...,
                stream_identifier: shared_pb2.StreamIdentifier | None = ...,
                stream_revision: builtins.int = ...,
                prepare_position: builtins.int = ...,
                commit_position: builtins.int = ...,
                metadata: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
                custom_metadata: builtins.bytes = ...,
                data: builtins.bytes = ...,
            ) -> None: ...
            def HasField(self, field_name: typing_extensions.Literal["id", b"id", "stream_identifier", b"stream_identifier"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing_extensions.Literal["commit_position", b"commit_position", "custom_metadata", b"custom_metadata", "data", b"data", "id", b"id", "metadata", b"metadata", "prepare_position", b"prepare_position", "stream_identifier", b"stream_identifier", "stream_revision", b"stream_revision"]) -> None: ...

        EVENT_FIELD_NUMBER: builtins.int
        LINK_FIELD_NUMBER: builtins.int
        COMMIT_POSITION_FIELD_NUMBER: builtins.int
        NO_POSITION_FIELD_NUMBER: builtins.int
        RETRY_COUNT_FIELD_NUMBER: builtins.int
        NO_RETRY_COUNT_FIELD_NUMBER: builtins.int
        @property
        def event(self) -> global___ReadResp.ReadEvent.RecordedEvent: ...
        @property
        def link(self) -> global___ReadResp.ReadEvent.RecordedEvent: ...
        commit_position: builtins.int
        @property
        def no_position(self) -> shared_pb2.Empty: ...
        retry_count: builtins.int
        @property
        def no_retry_count(self) -> shared_pb2.Empty: ...
        def __init__(
            self,
            *,
            event: global___ReadResp.ReadEvent.RecordedEvent | None = ...,
            link: global___ReadResp.ReadEvent.RecordedEvent | None = ...,
            commit_position: builtins.int = ...,
            no_position: shared_pb2.Empty | None = ...,
            retry_count: builtins.int = ...,
            no_retry_count: shared_pb2.Empty | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["commit_position", b"commit_position", "count", b"count", "event", b"event", "link", b"link", "no_position", b"no_position", "no_retry_count", b"no_retry_count", "position", b"position", "retry_count", b"retry_count"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["commit_position", b"commit_position", "count", b"count", "event", b"event", "link", b"link", "no_position", b"no_position", "no_retry_count", b"no_retry_count", "position", b"position", "retry_count", b"retry_count"]) -> None: ...
        @typing.overload
        def WhichOneof(self, oneof_group: typing_extensions.Literal["count", b"count"]) -> typing_extensions.Literal["retry_count", "no_retry_count"] | None: ...
        @typing.overload
        def WhichOneof(self, oneof_group: typing_extensions.Literal["position", b"position"]) -> typing_extensions.Literal["commit_position", "no_position"] | None: ...

    class SubscriptionConfirmation(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        SUBSCRIPTION_ID_FIELD_NUMBER: builtins.int
        subscription_id: builtins.str
        def __init__(
            self,
            *,
            subscription_id: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["subscription_id", b"subscription_id"]) -> None: ...

    EVENT_FIELD_NUMBER: builtins.int
    SUBSCRIPTION_CONFIRMATION_FIELD_NUMBER: builtins.int
    @property
    def event(self) -> global___ReadResp.ReadEvent: ...
    @property
    def subscription_confirmation(self) -> global___ReadResp.SubscriptionConfirmation: ...
    def __init__(
        self,
        *,
        event: global___ReadResp.ReadEvent | None = ...,
        subscription_confirmation: global___ReadResp.SubscriptionConfirmation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["content", b"content", "event", b"event", "subscription_confirmation", b"subscription_confirmation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["content", b"content", "event", b"event", "subscription_confirmation", b"subscription_confirmation"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["content", b"content"]) -> typing_extensions.Literal["event", "subscription_confirmation"] | None: ...

global___ReadResp = ReadResp

class CreateReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _ConsumerStrategy:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ConsumerStrategyEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[CreateReq._ConsumerStrategy.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        DispatchToSingle: CreateReq._ConsumerStrategy.ValueType  # 0
        RoundRobin: CreateReq._ConsumerStrategy.ValueType  # 1
        Pinned: CreateReq._ConsumerStrategy.ValueType  # 2

    class ConsumerStrategy(_ConsumerStrategy, metaclass=_ConsumerStrategyEnumTypeWrapper): ...
    DispatchToSingle: CreateReq.ConsumerStrategy.ValueType  # 0
    RoundRobin: CreateReq.ConsumerStrategy.ValueType  # 1
    Pinned: CreateReq.ConsumerStrategy.ValueType  # 2

    class Options(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        STREAM_FIELD_NUMBER: builtins.int
        ALL_FIELD_NUMBER: builtins.int
        STREAM_IDENTIFIER_FIELD_NUMBER: builtins.int
        GROUP_NAME_FIELD_NUMBER: builtins.int
        SETTINGS_FIELD_NUMBER: builtins.int
        @property
        def stream(self) -> global___CreateReq.StreamOptions: ...
        @property
        def all(self) -> global___CreateReq.AllOptions: ...
        @property
        def stream_identifier(self) -> shared_pb2.StreamIdentifier: ...
        group_name: builtins.str
        @property
        def settings(self) -> global___CreateReq.Settings: ...
        def __init__(
            self,
            *,
            stream: global___CreateReq.StreamOptions | None = ...,
            all: global___CreateReq.AllOptions | None = ...,
            stream_identifier: shared_pb2.StreamIdentifier | None = ...,
            group_name: builtins.str = ...,
            settings: global___CreateReq.Settings | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["all", b"all", "settings", b"settings", "stream", b"stream", "stream_identifier", b"stream_identifier", "stream_option", b"stream_option"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["all", b"all", "group_name", b"group_name", "settings", b"settings", "stream", b"stream", "stream_identifier", b"stream_identifier", "stream_option", b"stream_option"]) -> None: ...
        def WhichOneof(self, oneof_group: typing_extensions.Literal["stream_option", b"stream_option"]) -> typing_extensions.Literal["stream", "all"] | None: ...

    class StreamOptions(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        STREAM_IDENTIFIER_FIELD_NUMBER: builtins.int
        REVISION_FIELD_NUMBER: builtins.int
        START_FIELD_NUMBER: builtins.int
        END_FIELD_NUMBER: builtins.int
        @property
        def stream_identifier(self) -> shared_pb2.StreamIdentifier: ...
        revision: builtins.int
        @property
        def start(self) -> shared_pb2.Empty: ...
        @property
        def end(self) -> shared_pb2.Empty: ...
        def __init__(
            self,
            *,
            stream_identifier: shared_pb2.StreamIdentifier | None = ...,
            revision: builtins.int = ...,
            start: shared_pb2.Empty | None = ...,
            end: shared_pb2.Empty | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["end", b"end", "revision", b"revision", "revision_option", b"revision_option", "start", b"start", "stream_identifier", b"stream_identifier"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["end", b"end", "revision", b"revision", "revision_option", b"revision_option", "start", b"start", "stream_identifier", b"stream_identifier"]) -> None: ...
        def WhichOneof(self, oneof_group: typing_extensions.Literal["revision_option", b"revision_option"]) -> typing_extensions.Literal["revision", "start", "end"] | None: ...

    class AllOptions(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class FilterOptions(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            class Expression(google.protobuf.message.Message):
                DESCRIPTOR: google.protobuf.descriptor.Descriptor

                REGEX_FIELD_NUMBER: builtins.int
                PREFIX_FIELD_NUMBER: builtins.int
                regex: builtins.str
                @property
                def prefix(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
                def __init__(
                    self,
                    *,
                    regex: builtins.str = ...,
                    prefix: collections.abc.Iterable[builtins.str] | None = ...,
                ) -> None: ...
                def ClearField(self, field_name: typing_extensions.Literal["prefix", b"prefix", "regex", b"regex"]) -> None: ...

            STREAM_IDENTIFIER_FIELD_NUMBER: builtins.int
            EVENT_TYPE_FIELD_NUMBER: builtins.int
            MAX_FIELD_NUMBER: builtins.int
            COUNT_FIELD_NUMBER: builtins.int
            CHECKPOINTINTERVALMULTIPLIER_FIELD_NUMBER: builtins.int
            @property
            def stream_identifier(self) -> global___CreateReq.AllOptions.FilterOptions.Expression: ...
            @property
            def event_type(self) -> global___CreateReq.AllOptions.FilterOptions.Expression: ...
            max: builtins.int
            @property
            def count(self) -> shared_pb2.Empty: ...
            checkpointIntervalMultiplier: builtins.int
            def __init__(
                self,
                *,
                stream_identifier: global___CreateReq.AllOptions.FilterOptions.Expression | None = ...,
                event_type: global___CreateReq.AllOptions.FilterOptions.Expression | None = ...,
                max: builtins.int = ...,
                count: shared_pb2.Empty | None = ...,
                checkpointIntervalMultiplier: builtins.int = ...,
            ) -> None: ...
            def HasField(self, field_name: typing_extensions.Literal["count", b"count", "event_type", b"event_type", "filter", b"filter", "max", b"max", "stream_identifier", b"stream_identifier", "window", b"window"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing_extensions.Literal["checkpointIntervalMultiplier", b"checkpointIntervalMultiplier", "count", b"count", "event_type", b"event_type", "filter", b"filter", "max", b"max", "stream_identifier", b"stream_identifier", "window", b"window"]) -> None: ...
            @typing.overload
            def WhichOneof(self, oneof_group: typing_extensions.Literal["filter", b"filter"]) -> typing_extensions.Literal["stream_identifier", "event_type"] | None: ...
            @typing.overload
            def WhichOneof(self, oneof_group: typing_extensions.Literal["window", b"window"]) -> typing_extensions.Literal["max", "count"] | None: ...

        POSITION_FIELD_NUMBER: builtins.int
        START_FIELD_NUMBER: builtins.int
        END_FIELD_NUMBER: builtins.int
        FILTER_FIELD_NUMBER: builtins.int
        NO_FILTER_FIELD_NUMBER: builtins.int
        @property
        def position(self) -> global___CreateReq.Position: ...
        @property
        def start(self) -> shared_pb2.Empty: ...
        @property
        def end(self) -> shared_pb2.Empty: ...
        @property
        def filter(self) -> global___CreateReq.AllOptions.FilterOptions: ...
        @property
        def no_filter(self) -> shared_pb2.Empty: ...
        def __init__(
            self,
            *,
            position: global___CreateReq.Position | None = ...,
            start: shared_pb2.Empty | None = ...,
            end: shared_pb2.Empty | None = ...,
            filter: global___CreateReq.AllOptions.FilterOptions | None = ...,
            no_filter: shared_pb2.Empty | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["all_option", b"all_option", "end", b"end", "filter", b"filter", "filter_option", b"filter_option", "no_filter", b"no_filter", "position", b"position", "start", b"start"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["all_option", b"all_option", "end", b"end", "filter", b"filter", "filter_option", b"filter_option", "no_filter", b"no_filter", "position", b"position", "start", b"start"]) -> None: ...
        @typing.overload
        def WhichOneof(self, oneof_group: typing_extensions.Literal["all_option", b"all_option"]) -> typing_extensions.Literal["position", "start", "end"] | None: ...
        @typing.overload
        def WhichOneof(self, oneof_group: typing_extensions.Literal["filter_option", b"filter_option"]) -> typing_extensions.Literal["filter", "no_filter"] | None: ...

    class Position(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        COMMIT_POSITION_FIELD_NUMBER: builtins.int
        PREPARE_POSITION_FIELD_NUMBER: builtins.int
        commit_position: builtins.int
        prepare_position: builtins.int
        def __init__(
            self,
            *,
            commit_position: builtins.int = ...,
            prepare_position: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["commit_position", b"commit_position", "prepare_position", b"prepare_position"]) -> None: ...

    class Settings(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        RESOLVE_LINKS_FIELD_NUMBER: builtins.int
        REVISION_FIELD_NUMBER: builtins.int
        EXTRA_STATISTICS_FIELD_NUMBER: builtins.int
        MAX_RETRY_COUNT_FIELD_NUMBER: builtins.int
        MIN_CHECKPOINT_COUNT_FIELD_NUMBER: builtins.int
        MAX_CHECKPOINT_COUNT_FIELD_NUMBER: builtins.int
        MAX_SUBSCRIBER_COUNT_FIELD_NUMBER: builtins.int
        LIVE_BUFFER_SIZE_FIELD_NUMBER: builtins.int
        READ_BATCH_SIZE_FIELD_NUMBER: builtins.int
        HISTORY_BUFFER_SIZE_FIELD_NUMBER: builtins.int
        NAMED_CONSUMER_STRATEGY_FIELD_NUMBER: builtins.int
        MESSAGE_TIMEOUT_TICKS_FIELD_NUMBER: builtins.int
        MESSAGE_TIMEOUT_MS_FIELD_NUMBER: builtins.int
        CHECKPOINT_AFTER_TICKS_FIELD_NUMBER: builtins.int
        CHECKPOINT_AFTER_MS_FIELD_NUMBER: builtins.int
        CONSUMER_STRATEGY_FIELD_NUMBER: builtins.int
        resolve_links: builtins.bool
        revision: builtins.int
        extra_statistics: builtins.bool
        max_retry_count: builtins.int
        min_checkpoint_count: builtins.int
        max_checkpoint_count: builtins.int
        max_subscriber_count: builtins.int
        live_buffer_size: builtins.int
        read_batch_size: builtins.int
        history_buffer_size: builtins.int
        named_consumer_strategy: global___CreateReq.ConsumerStrategy.ValueType
        message_timeout_ticks: builtins.int
        message_timeout_ms: builtins.int
        checkpoint_after_ticks: builtins.int
        checkpoint_after_ms: builtins.int
        consumer_strategy: builtins.str
        def __init__(
            self,
            *,
            resolve_links: builtins.bool = ...,
            revision: builtins.int = ...,
            extra_statistics: builtins.bool = ...,
            max_retry_count: builtins.int = ...,
            min_checkpoint_count: builtins.int = ...,
            max_checkpoint_count: builtins.int = ...,
            max_subscriber_count: builtins.int = ...,
            live_buffer_size: builtins.int = ...,
            read_batch_size: builtins.int = ...,
            history_buffer_size: builtins.int = ...,
            named_consumer_strategy: global___CreateReq.ConsumerStrategy.ValueType = ...,
            message_timeout_ticks: builtins.int = ...,
            message_timeout_ms: builtins.int = ...,
            checkpoint_after_ticks: builtins.int = ...,
            checkpoint_after_ms: builtins.int = ...,
            consumer_strategy: builtins.str = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["checkpoint_after", b"checkpoint_after", "checkpoint_after_ms", b"checkpoint_after_ms", "checkpoint_after_ticks", b"checkpoint_after_ticks", "message_timeout", b"message_timeout", "message_timeout_ms", b"message_timeout_ms", "message_timeout_ticks", b"message_timeout_ticks"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["checkpoint_after", b"checkpoint_after", "checkpoint_after_ms", b"checkpoint_after_ms", "checkpoint_after_ticks", b"checkpoint_after_ticks", "consumer_strategy", b"consumer_strategy", "extra_statistics", b"extra_statistics", "history_buffer_size", b"history_buffer_size", "live_buffer_size", b"live_buffer_size", "max_checkpoint_count", b"max_checkpoint_count", "max_retry_count", b"max_retry_count", "max_subscriber_count", b"max_subscriber_count", "message_timeout", b"message_timeout", "message_timeout_ms", b"message_timeout_ms", "message_timeout_ticks", b"message_timeout_ticks", "min_checkpoint_count", b"min_checkpoint_count", "named_consumer_strategy", b"named_consumer_strategy", "read_batch_size", b"read_batch_size", "resolve_links", b"resolve_links", "revision", b"revision"]) -> None: ...
        @typing.overload
        def WhichOneof(self, oneof_group: typing_extensions.Literal["checkpoint_after", b"checkpoint_after"]) -> typing_extensions.Literal["checkpoint_after_ticks", "checkpoint_after_ms"] | None: ...
        @typing.overload
        def WhichOneof(self, oneof_group: typing_extensions.Literal["message_timeout", b"message_timeout"]) -> typing_extensions.Literal["message_timeout_ticks", "message_timeout_ms"] | None: ...

    OPTIONS_FIELD_NUMBER: builtins.int
    @property
    def options(self) -> global___CreateReq.Options: ...
    def __init__(
        self,
        *,
        options: global___CreateReq.Options | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["options", b"options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["options", b"options"]) -> None: ...

global___CreateReq = CreateReq

class CreateResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___CreateResp = CreateResp

class UpdateReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _ConsumerStrategy:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ConsumerStrategyEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[UpdateReq._ConsumerStrategy.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        DispatchToSingle: UpdateReq._ConsumerStrategy.ValueType  # 0
        RoundRobin: UpdateReq._ConsumerStrategy.ValueType  # 1
        Pinned: UpdateReq._ConsumerStrategy.ValueType  # 2

    class ConsumerStrategy(_ConsumerStrategy, metaclass=_ConsumerStrategyEnumTypeWrapper): ...
    DispatchToSingle: UpdateReq.ConsumerStrategy.ValueType  # 0
    RoundRobin: UpdateReq.ConsumerStrategy.ValueType  # 1
    Pinned: UpdateReq.ConsumerStrategy.ValueType  # 2

    class Options(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        STREAM_FIELD_NUMBER: builtins.int
        ALL_FIELD_NUMBER: builtins.int
        STREAM_IDENTIFIER_FIELD_NUMBER: builtins.int
        GROUP_NAME_FIELD_NUMBER: builtins.int
        SETTINGS_FIELD_NUMBER: builtins.int
        @property
        def stream(self) -> global___UpdateReq.StreamOptions: ...
        @property
        def all(self) -> global___UpdateReq.AllOptions: ...
        @property
        def stream_identifier(self) -> shared_pb2.StreamIdentifier: ...
        group_name: builtins.str
        @property
        def settings(self) -> global___UpdateReq.Settings: ...
        def __init__(
            self,
            *,
            stream: global___UpdateReq.StreamOptions | None = ...,
            all: global___UpdateReq.AllOptions | None = ...,
            stream_identifier: shared_pb2.StreamIdentifier | None = ...,
            group_name: builtins.str = ...,
            settings: global___UpdateReq.Settings | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["all", b"all", "settings", b"settings", "stream", b"stream", "stream_identifier", b"stream_identifier", "stream_option", b"stream_option"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["all", b"all", "group_name", b"group_name", "settings", b"settings", "stream", b"stream", "stream_identifier", b"stream_identifier", "stream_option", b"stream_option"]) -> None: ...
        def WhichOneof(self, oneof_group: typing_extensions.Literal["stream_option", b"stream_option"]) -> typing_extensions.Literal["stream", "all"] | None: ...

    class StreamOptions(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        STREAM_IDENTIFIER_FIELD_NUMBER: builtins.int
        REVISION_FIELD_NUMBER: builtins.int
        START_FIELD_NUMBER: builtins.int
        END_FIELD_NUMBER: builtins.int
        @property
        def stream_identifier(self) -> shared_pb2.StreamIdentifier: ...
        revision: builtins.int
        @property
        def start(self) -> shared_pb2.Empty: ...
        @property
        def end(self) -> shared_pb2.Empty: ...
        def __init__(
            self,
            *,
            stream_identifier: shared_pb2.StreamIdentifier | None = ...,
            revision: builtins.int = ...,
            start: shared_pb2.Empty | None = ...,
            end: shared_pb2.Empty | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["end", b"end", "revision", b"revision", "revision_option", b"revision_option", "start", b"start", "stream_identifier", b"stream_identifier"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["end", b"end", "revision", b"revision", "revision_option", b"revision_option", "start", b"start", "stream_identifier", b"stream_identifier"]) -> None: ...
        def WhichOneof(self, oneof_group: typing_extensions.Literal["revision_option", b"revision_option"]) -> typing_extensions.Literal["revision", "start", "end"] | None: ...

    class AllOptions(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        POSITION_FIELD_NUMBER: builtins.int
        START_FIELD_NUMBER: builtins.int
        END_FIELD_NUMBER: builtins.int
        @property
        def position(self) -> global___UpdateReq.Position: ...
        @property
        def start(self) -> shared_pb2.Empty: ...
        @property
        def end(self) -> shared_pb2.Empty: ...
        def __init__(
            self,
            *,
            position: global___UpdateReq.Position | None = ...,
            start: shared_pb2.Empty | None = ...,
            end: shared_pb2.Empty | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["all_option", b"all_option", "end", b"end", "position", b"position", "start", b"start"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["all_option", b"all_option", "end", b"end", "position", b"position", "start", b"start"]) -> None: ...
        def WhichOneof(self, oneof_group: typing_extensions.Literal["all_option", b"all_option"]) -> typing_extensions.Literal["position", "start", "end"] | None: ...

    class Position(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        COMMIT_POSITION_FIELD_NUMBER: builtins.int
        PREPARE_POSITION_FIELD_NUMBER: builtins.int
        commit_position: builtins.int
        prepare_position: builtins.int
        def __init__(
            self,
            *,
            commit_position: builtins.int = ...,
            prepare_position: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["commit_position", b"commit_position", "prepare_position", b"prepare_position"]) -> None: ...

    class Settings(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        RESOLVE_LINKS_FIELD_NUMBER: builtins.int
        REVISION_FIELD_NUMBER: builtins.int
        EXTRA_STATISTICS_FIELD_NUMBER: builtins.int
        MAX_RETRY_COUNT_FIELD_NUMBER: builtins.int
        MIN_CHECKPOINT_COUNT_FIELD_NUMBER: builtins.int
        MAX_CHECKPOINT_COUNT_FIELD_NUMBER: builtins.int
        MAX_SUBSCRIBER_COUNT_FIELD_NUMBER: builtins.int
        LIVE_BUFFER_SIZE_FIELD_NUMBER: builtins.int
        READ_BATCH_SIZE_FIELD_NUMBER: builtins.int
        HISTORY_BUFFER_SIZE_FIELD_NUMBER: builtins.int
        NAMED_CONSUMER_STRATEGY_FIELD_NUMBER: builtins.int
        MESSAGE_TIMEOUT_TICKS_FIELD_NUMBER: builtins.int
        MESSAGE_TIMEOUT_MS_FIELD_NUMBER: builtins.int
        CHECKPOINT_AFTER_TICKS_FIELD_NUMBER: builtins.int
        CHECKPOINT_AFTER_MS_FIELD_NUMBER: builtins.int
        resolve_links: builtins.bool
        revision: builtins.int
        extra_statistics: builtins.bool
        max_retry_count: builtins.int
        min_checkpoint_count: builtins.int
        max_checkpoint_count: builtins.int
        max_subscriber_count: builtins.int
        live_buffer_size: builtins.int
        read_batch_size: builtins.int
        history_buffer_size: builtins.int
        named_consumer_strategy: global___UpdateReq.ConsumerStrategy.ValueType
        message_timeout_ticks: builtins.int
        message_timeout_ms: builtins.int
        checkpoint_after_ticks: builtins.int
        checkpoint_after_ms: builtins.int
        def __init__(
            self,
            *,
            resolve_links: builtins.bool = ...,
            revision: builtins.int = ...,
            extra_statistics: builtins.bool = ...,
            max_retry_count: builtins.int = ...,
            min_checkpoint_count: builtins.int = ...,
            max_checkpoint_count: builtins.int = ...,
            max_subscriber_count: builtins.int = ...,
            live_buffer_size: builtins.int = ...,
            read_batch_size: builtins.int = ...,
            history_buffer_size: builtins.int = ...,
            named_consumer_strategy: global___UpdateReq.ConsumerStrategy.ValueType = ...,
            message_timeout_ticks: builtins.int = ...,
            message_timeout_ms: builtins.int = ...,
            checkpoint_after_ticks: builtins.int = ...,
            checkpoint_after_ms: builtins.int = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["checkpoint_after", b"checkpoint_after", "checkpoint_after_ms", b"checkpoint_after_ms", "checkpoint_after_ticks", b"checkpoint_after_ticks", "message_timeout", b"message_timeout", "message_timeout_ms", b"message_timeout_ms", "message_timeout_ticks", b"message_timeout_ticks"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["checkpoint_after", b"checkpoint_after", "checkpoint_after_ms", b"checkpoint_after_ms", "checkpoint_after_ticks", b"checkpoint_after_ticks", "extra_statistics", b"extra_statistics", "history_buffer_size", b"history_buffer_size", "live_buffer_size", b"live_buffer_size", "max_checkpoint_count", b"max_checkpoint_count", "max_retry_count", b"max_retry_count", "max_subscriber_count", b"max_subscriber_count", "message_timeout", b"message_timeout", "message_timeout_ms", b"message_timeout_ms", "message_timeout_ticks", b"message_timeout_ticks", "min_checkpoint_count", b"min_checkpoint_count", "named_consumer_strategy", b"named_consumer_strategy", "read_batch_size", b"read_batch_size", "resolve_links", b"resolve_links", "revision", b"revision"]) -> None: ...
        @typing.overload
        def WhichOneof(self, oneof_group: typing_extensions.Literal["checkpoint_after", b"checkpoint_after"]) -> typing_extensions.Literal["checkpoint_after_ticks", "checkpoint_after_ms"] | None: ...
        @typing.overload
        def WhichOneof(self, oneof_group: typing_extensions.Literal["message_timeout", b"message_timeout"]) -> typing_extensions.Literal["message_timeout_ticks", "message_timeout_ms"] | None: ...

    OPTIONS_FIELD_NUMBER: builtins.int
    @property
    def options(self) -> global___UpdateReq.Options: ...
    def __init__(
        self,
        *,
        options: global___UpdateReq.Options | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["options", b"options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["options", b"options"]) -> None: ...

global___UpdateReq = UpdateReq

class UpdateResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___UpdateResp = UpdateResp

class DeleteReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class Options(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        STREAM_IDENTIFIER_FIELD_NUMBER: builtins.int
        ALL_FIELD_NUMBER: builtins.int
        GROUP_NAME_FIELD_NUMBER: builtins.int
        @property
        def stream_identifier(self) -> shared_pb2.StreamIdentifier: ...
        @property
        def all(self) -> shared_pb2.Empty: ...
        group_name: builtins.str
        def __init__(
            self,
            *,
            stream_identifier: shared_pb2.StreamIdentifier | None = ...,
            all: shared_pb2.Empty | None = ...,
            group_name: builtins.str = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["all", b"all", "stream_identifier", b"stream_identifier", "stream_option", b"stream_option"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["all", b"all", "group_name", b"group_name", "stream_identifier", b"stream_identifier", "stream_option", b"stream_option"]) -> None: ...
        def WhichOneof(self, oneof_group: typing_extensions.Literal["stream_option", b"stream_option"]) -> typing_extensions.Literal["stream_identifier", "all"] | None: ...

    OPTIONS_FIELD_NUMBER: builtins.int
    @property
    def options(self) -> global___DeleteReq.Options: ...
    def __init__(
        self,
        *,
        options: global___DeleteReq.Options | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["options", b"options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["options", b"options"]) -> None: ...

global___DeleteReq = DeleteReq

class DeleteResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteResp = DeleteResp

class GetInfoReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class Options(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        STREAM_IDENTIFIER_FIELD_NUMBER: builtins.int
        ALL_FIELD_NUMBER: builtins.int
        GROUP_NAME_FIELD_NUMBER: builtins.int
        @property
        def stream_identifier(self) -> shared_pb2.StreamIdentifier: ...
        @property
        def all(self) -> shared_pb2.Empty: ...
        group_name: builtins.str
        def __init__(
            self,
            *,
            stream_identifier: shared_pb2.StreamIdentifier | None = ...,
            all: shared_pb2.Empty | None = ...,
            group_name: builtins.str = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["all", b"all", "stream_identifier", b"stream_identifier", "stream_option", b"stream_option"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["all", b"all", "group_name", b"group_name", "stream_identifier", b"stream_identifier", "stream_option", b"stream_option"]) -> None: ...
        def WhichOneof(self, oneof_group: typing_extensions.Literal["stream_option", b"stream_option"]) -> typing_extensions.Literal["stream_identifier", "all"] | None: ...

    OPTIONS_FIELD_NUMBER: builtins.int
    @property
    def options(self) -> global___GetInfoReq.Options: ...
    def __init__(
        self,
        *,
        options: global___GetInfoReq.Options | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["options", b"options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["options", b"options"]) -> None: ...

global___GetInfoReq = GetInfoReq

class GetInfoResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBSCRIPTION_INFO_FIELD_NUMBER: builtins.int
    @property
    def subscription_info(self) -> global___SubscriptionInfo: ...
    def __init__(
        self,
        *,
        subscription_info: global___SubscriptionInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["subscription_info", b"subscription_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["subscription_info", b"subscription_info"]) -> None: ...

global___GetInfoResp = GetInfoResp

class SubscriptionInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class ConnectionInfo(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        FROM_FIELD_NUMBER: builtins.int
        USERNAME_FIELD_NUMBER: builtins.int
        AVERAGE_ITEMS_PER_SECOND_FIELD_NUMBER: builtins.int
        TOTAL_ITEMS_FIELD_NUMBER: builtins.int
        COUNT_SINCE_LAST_MEASUREMENT_FIELD_NUMBER: builtins.int
        OBSERVED_MEASUREMENTS_FIELD_NUMBER: builtins.int
        AVAILABLE_SLOTS_FIELD_NUMBER: builtins.int
        IN_FLIGHT_MESSAGES_FIELD_NUMBER: builtins.int
        CONNECTION_NAME_FIELD_NUMBER: builtins.int
        username: builtins.str
        average_items_per_second: builtins.int
        total_items: builtins.int
        count_since_last_measurement: builtins.int
        @property
        def observed_measurements(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SubscriptionInfo.Measurement]: ...
        available_slots: builtins.int
        in_flight_messages: builtins.int
        connection_name: builtins.str
        def __init__(
            self,
            *,
            username: builtins.str = ...,
            average_items_per_second: builtins.int = ...,
            total_items: builtins.int = ...,
            count_since_last_measurement: builtins.int = ...,
            observed_measurements: collections.abc.Iterable[global___SubscriptionInfo.Measurement] | None = ...,
            available_slots: builtins.int = ...,
            in_flight_messages: builtins.int = ...,
            connection_name: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["available_slots", b"available_slots", "average_items_per_second", b"average_items_per_second", "connection_name", b"connection_name", "count_since_last_measurement", b"count_since_last_measurement", "from", b"from", "in_flight_messages", b"in_flight_messages", "observed_measurements", b"observed_measurements", "total_items", b"total_items", "username", b"username"]) -> None: ...

    class Measurement(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.int
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    EVENT_SOURCE_FIELD_NUMBER: builtins.int
    GROUP_NAME_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    CONNECTIONS_FIELD_NUMBER: builtins.int
    AVERAGE_PER_SECOND_FIELD_NUMBER: builtins.int
    TOTAL_ITEMS_FIELD_NUMBER: builtins.int
    COUNT_SINCE_LAST_MEASUREMENT_FIELD_NUMBER: builtins.int
    LAST_CHECKPOINTED_EVENT_POSITION_FIELD_NUMBER: builtins.int
    LAST_KNOWN_EVENT_POSITION_FIELD_NUMBER: builtins.int
    RESOLVE_LINK_TOS_FIELD_NUMBER: builtins.int
    START_FROM_FIELD_NUMBER: builtins.int
    MESSAGE_TIMEOUT_MILLISECONDS_FIELD_NUMBER: builtins.int
    EXTRA_STATISTICS_FIELD_NUMBER: builtins.int
    MAX_RETRY_COUNT_FIELD_NUMBER: builtins.int
    LIVE_BUFFER_SIZE_FIELD_NUMBER: builtins.int
    BUFFER_SIZE_FIELD_NUMBER: builtins.int
    READ_BATCH_SIZE_FIELD_NUMBER: builtins.int
    CHECK_POINT_AFTER_MILLISECONDS_FIELD_NUMBER: builtins.int
    MIN_CHECK_POINT_COUNT_FIELD_NUMBER: builtins.int
    MAX_CHECK_POINT_COUNT_FIELD_NUMBER: builtins.int
    READ_BUFFER_COUNT_FIELD_NUMBER: builtins.int
    LIVE_BUFFER_COUNT_FIELD_NUMBER: builtins.int
    RETRY_BUFFER_COUNT_FIELD_NUMBER: builtins.int
    TOTAL_IN_FLIGHT_MESSAGES_FIELD_NUMBER: builtins.int
    OUTSTANDING_MESSAGES_COUNT_FIELD_NUMBER: builtins.int
    NAMED_CONSUMER_STRATEGY_FIELD_NUMBER: builtins.int
    MAX_SUBSCRIBER_COUNT_FIELD_NUMBER: builtins.int
    PARKED_MESSAGE_COUNT_FIELD_NUMBER: builtins.int
    event_source: builtins.str
    group_name: builtins.str
    status: builtins.str
    @property
    def connections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SubscriptionInfo.ConnectionInfo]: ...
    average_per_second: builtins.int
    total_items: builtins.int
    count_since_last_measurement: builtins.int
    last_checkpointed_event_position: builtins.str
    last_known_event_position: builtins.str
    resolve_link_tos: builtins.bool
    start_from: builtins.str
    message_timeout_milliseconds: builtins.int
    extra_statistics: builtins.bool
    max_retry_count: builtins.int
    live_buffer_size: builtins.int
    buffer_size: builtins.int
    read_batch_size: builtins.int
    check_point_after_milliseconds: builtins.int
    min_check_point_count: builtins.int
    max_check_point_count: builtins.int
    read_buffer_count: builtins.int
    live_buffer_count: builtins.int
    retry_buffer_count: builtins.int
    total_in_flight_messages: builtins.int
    outstanding_messages_count: builtins.int
    named_consumer_strategy: builtins.str
    max_subscriber_count: builtins.int
    parked_message_count: builtins.int
    def __init__(
        self,
        *,
        event_source: builtins.str = ...,
        group_name: builtins.str = ...,
        status: builtins.str = ...,
        connections: collections.abc.Iterable[global___SubscriptionInfo.ConnectionInfo] | None = ...,
        average_per_second: builtins.int = ...,
        total_items: builtins.int = ...,
        count_since_last_measurement: builtins.int = ...,
        last_checkpointed_event_position: builtins.str = ...,
        last_known_event_position: builtins.str = ...,
        resolve_link_tos: builtins.bool = ...,
        start_from: builtins.str = ...,
        message_timeout_milliseconds: builtins.int = ...,
        extra_statistics: builtins.bool = ...,
        max_retry_count: builtins.int = ...,
        live_buffer_size: builtins.int = ...,
        buffer_size: builtins.int = ...,
        read_batch_size: builtins.int = ...,
        check_point_after_milliseconds: builtins.int = ...,
        min_check_point_count: builtins.int = ...,
        max_check_point_count: builtins.int = ...,
        read_buffer_count: builtins.int = ...,
        live_buffer_count: builtins.int = ...,
        retry_buffer_count: builtins.int = ...,
        total_in_flight_messages: builtins.int = ...,
        outstanding_messages_count: builtins.int = ...,
        named_consumer_strategy: builtins.str = ...,
        max_subscriber_count: builtins.int = ...,
        parked_message_count: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["average_per_second", b"average_per_second", "buffer_size", b"buffer_size", "check_point_after_milliseconds", b"check_point_after_milliseconds", "connections", b"connections", "count_since_last_measurement", b"count_since_last_measurement", "event_source", b"event_source", "extra_statistics", b"extra_statistics", "group_name", b"group_name", "last_checkpointed_event_position", b"last_checkpointed_event_position", "last_known_event_position", b"last_known_event_position", "live_buffer_count", b"live_buffer_count", "live_buffer_size", b"live_buffer_size", "max_check_point_count", b"max_check_point_count", "max_retry_count", b"max_retry_count", "max_subscriber_count", b"max_subscriber_count", "message_timeout_milliseconds", b"message_timeout_milliseconds", "min_check_point_count", b"min_check_point_count", "named_consumer_strategy", b"named_consumer_strategy", "outstanding_messages_count", b"outstanding_messages_count", "parked_message_count", b"parked_message_count", "read_batch_size", b"read_batch_size", "read_buffer_count", b"read_buffer_count", "resolve_link_tos", b"resolve_link_tos", "retry_buffer_count", b"retry_buffer_count", "start_from", b"start_from", "status", b"status", "total_in_flight_messages", b"total_in_flight_messages", "total_items", b"total_items"]) -> None: ...

global___SubscriptionInfo = SubscriptionInfo

class ReplayParkedReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class Options(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        GROUP_NAME_FIELD_NUMBER: builtins.int
        STREAM_IDENTIFIER_FIELD_NUMBER: builtins.int
        ALL_FIELD_NUMBER: builtins.int
        STOP_AT_FIELD_NUMBER: builtins.int
        NO_LIMIT_FIELD_NUMBER: builtins.int
        group_name: builtins.str
        @property
        def stream_identifier(self) -> shared_pb2.StreamIdentifier: ...
        @property
        def all(self) -> shared_pb2.Empty: ...
        stop_at: builtins.int
        @property
        def no_limit(self) -> shared_pb2.Empty: ...
        def __init__(
            self,
            *,
            group_name: builtins.str = ...,
            stream_identifier: shared_pb2.StreamIdentifier | None = ...,
            all: shared_pb2.Empty | None = ...,
            stop_at: builtins.int = ...,
            no_limit: shared_pb2.Empty | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["all", b"all", "no_limit", b"no_limit", "stop_at", b"stop_at", "stop_at_option", b"stop_at_option", "stream_identifier", b"stream_identifier", "stream_option", b"stream_option"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["all", b"all", "group_name", b"group_name", "no_limit", b"no_limit", "stop_at", b"stop_at", "stop_at_option", b"stop_at_option", "stream_identifier", b"stream_identifier", "stream_option", b"stream_option"]) -> None: ...
        @typing.overload
        def WhichOneof(self, oneof_group: typing_extensions.Literal["stop_at_option", b"stop_at_option"]) -> typing_extensions.Literal["stop_at", "no_limit"] | None: ...
        @typing.overload
        def WhichOneof(self, oneof_group: typing_extensions.Literal["stream_option", b"stream_option"]) -> typing_extensions.Literal["stream_identifier", "all"] | None: ...

    OPTIONS_FIELD_NUMBER: builtins.int
    @property
    def options(self) -> global___ReplayParkedReq.Options: ...
    def __init__(
        self,
        *,
        options: global___ReplayParkedReq.Options | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["options", b"options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["options", b"options"]) -> None: ...

global___ReplayParkedReq = ReplayParkedReq

class ReplayParkedResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ReplayParkedResp = ReplayParkedResp

class ListReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class Options(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        LIST_ALL_SUBSCRIPTIONS_FIELD_NUMBER: builtins.int
        LIST_FOR_STREAM_FIELD_NUMBER: builtins.int
        @property
        def list_all_subscriptions(self) -> shared_pb2.Empty: ...
        @property
        def list_for_stream(self) -> global___ListReq.StreamOption: ...
        def __init__(
            self,
            *,
            list_all_subscriptions: shared_pb2.Empty | None = ...,
            list_for_stream: global___ListReq.StreamOption | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["list_all_subscriptions", b"list_all_subscriptions", "list_for_stream", b"list_for_stream", "list_option", b"list_option"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["list_all_subscriptions", b"list_all_subscriptions", "list_for_stream", b"list_for_stream", "list_option", b"list_option"]) -> None: ...
        def WhichOneof(self, oneof_group: typing_extensions.Literal["list_option", b"list_option"]) -> typing_extensions.Literal["list_all_subscriptions", "list_for_stream"] | None: ...

    class StreamOption(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        STREAM_FIELD_NUMBER: builtins.int
        ALL_FIELD_NUMBER: builtins.int
        @property
        def stream(self) -> shared_pb2.StreamIdentifier: ...
        @property
        def all(self) -> shared_pb2.Empty: ...
        def __init__(
            self,
            *,
            stream: shared_pb2.StreamIdentifier | None = ...,
            all: shared_pb2.Empty | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["all", b"all", "stream", b"stream", "stream_option", b"stream_option"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["all", b"all", "stream", b"stream", "stream_option", b"stream_option"]) -> None: ...
        def WhichOneof(self, oneof_group: typing_extensions.Literal["stream_option", b"stream_option"]) -> typing_extensions.Literal["stream", "all"] | None: ...

    OPTIONS_FIELD_NUMBER: builtins.int
    @property
    def options(self) -> global___ListReq.Options: ...
    def __init__(
        self,
        *,
        options: global___ListReq.Options | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["options", b"options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["options", b"options"]) -> None: ...

global___ListReq = ListReq

class ListResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBSCRIPTIONS_FIELD_NUMBER: builtins.int
    @property
    def subscriptions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SubscriptionInfo]: ...
    def __init__(
        self,
        *,
        subscriptions: collections.abc.Iterable[global___SubscriptionInfo] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["subscriptions", b"subscriptions"]) -> None: ...

global___ListResp = ListResp



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class StatsReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USE_METADATA_FIELD_NUMBER: builtins.int
    REFRESH_TIME_PERIOD_IN_MS_FIELD_NUMBER: builtins.int
    use_metadata: builtins.bool
    refresh_time_period_in_ms: builtins.int
    def __init__(
        self,
        *,
        use_metadata: builtins.bool = ...,
        refresh_time_period_in_ms: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["refresh_time_period_in_ms", b"refresh_time_period_in_ms", "use_metadata", b"use_metadata"]) -> None: ...

global___StatsReq = StatsReq

class StatsResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class StatsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    STATS_FIELD_NUMBER: builtins.int
    @property
    def stats(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        stats: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["stats", b"stats"]) -> None: ...

global___StatsResp = StatsResp



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class StartScavengeReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class Options(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        THREAD_COUNT_FIELD_NUMBER: builtins.int
        START_FROM_CHUNK_FIELD_NUMBER: builtins.int
        thread_count: builtins.int
        start_from_chunk: builtins.int
        def __init__(
            self,
            *,
            thread_count: builtins.int = ...,
            start_from_chunk: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["start_from_chunk", b"start_from_chunk", "thread_count", b"thread_count"]) -> None: ...

    OPTIONS_FIELD_NUMBER: builtins.int
    @property
    def options(self) -> global___StartScavengeReq.Options: ...
    def __init__(
        self,
        *,
        options: global___StartScavengeReq.Options | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["options", b"options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["options", b"options"]) -> None: ...

global___StartScavengeReq = StartScavengeReq

class StopScavengeReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class Options(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        SCAVENGE_ID_FIELD_NUMBER: builtins.int
        scavenge_id: builtins.str
        def __init__(
            self,
            *,
            scavenge_id: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["scavenge_id", b"scavenge_id"]) -> None: ...

    OPTIONS_FIELD_NUMBER: builtins.int
    @property
    def options(self) -> global___StopScavengeReq.Options: ...
    def __init__(
        self,
        *,
        options: global___StopScavengeReq.Options | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["options", b"options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["options", b"options"]) -> None: ...

global___StopScavengeReq = StopScavengeReq

class ScavengeResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _ScavengeResult:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ScavengeResultEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ScavengeResp._ScavengeResult.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        Started: ScavengeResp._ScavengeResult.ValueType  # 0
        InProgress: ScavengeResp._ScavengeResult.ValueType  # 1
        Stopped: ScavengeResp._ScavengeResult.ValueType  # 2

    class ScavengeResult(_ScavengeResult, metaclass=_ScavengeResultEnumTypeWrapper): ...
    Started: ScavengeResp.ScavengeResult.ValueType  # 0
    InProgress: ScavengeResp.ScavengeResult.ValueType  # 1
    Stopped: ScavengeResp.ScavengeResult.ValueType  # 2

    SCAVENGE_ID_FIELD_NUMBER: builtins.int
    SCAVENGE_RESULT_FIELD_NUMBER: builtins.int
    scavenge_id: builtins.str
    scavenge_result: global___ScavengeResp.ScavengeResult.ValueType
    def __init__(
        self,
        *,
        scavenge_id: builtins.str = ...,
        scavenge_result: global___ScavengeResp.ScavengeResult.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["scavenge_id", b"scavenge_id", "scavenge_result", b"scavenge_result"]) -> None: ...

global___ScavengeResp = ScavengeResp

class SetNodePriorityReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIORITY_FIELD_NUMBER: builtins.int
    priority: builtins.int
    def __init__(
        self,
        *,
        priority: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["priority", b"priority"]) -> None: ...

global___SetNodePriorityReq = SetNodePriorityReq



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: projections.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from . import shared_pb2 as shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11projections.proto\x12\x1e\x65vent_store.client.projections\x1a\x1cgoogle/protobuf/struct.proto\x1a\x0cshared.proto\"\xb3\x03\n\tCreateReq\x12\x42\n\x07options\x18\x01 \x01(\x0b\x32\x31.event_store.client.projections.CreateReq.Options\x1a\xe1\x02\n\x07Options\x12-\n\x08one_time\x18\x01 \x01(\x0b\x32\x19.event_store.client.EmptyH\x00\x12P\n\ttransient\x18\x02 \x01(\x0b\x32;.event_store.client.projections.CreateReq.Options.TransientH\x00\x12R\n\ncontinuous\x18\x03 \x01(\x0b\x32<.event_store.client.projections.CreateReq.Options.ContinuousH\x00\x12\r\n\x05query\x18\x04 \x01(\t\x1a\x19\n\tTransient\x12\x0c\n\x04name\x18\x01 \x01(\t\x1aO\n\nContinuous\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0c\x65mit_enabled\x18\x02 \x01(\x08\x12\x1d\n\x15track_emitted_streams\x18\x03 \x01(\x08\x42\x06\n\x04mode\"\x0c\n\nCreateResp\"\xd5\x01\n\tUpdateReq\x12\x42\n\x07options\x18\x01 \x01(\x0b\x32\x31.event_store.client.projections.UpdateReq.Options\x1a\x83\x01\n\x07Options\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05query\x18\x02 \x01(\t\x12\x16\n\x0c\x65mit_enabled\x18\x03 \x01(\x08H\x00\x12\x34\n\x0fno_emit_options\x18\x04 \x01(\x0b\x32\x19.event_store.client.EmptyH\x00\x42\r\n\x0b\x65mit_option\"\x0c\n\nUpdateResp\"\xc7\x01\n\tDeleteReq\x12\x42\n\x07options\x18\x01 \x01(\x0b\x32\x31.event_store.client.projections.DeleteReq.Options\x1av\n\x07Options\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1e\n\x16\x64\x65lete_emitted_streams\x18\x02 \x01(\x08\x12\x1b\n\x13\x64\x65lete_state_stream\x18\x03 \x01(\x08\x12 \n\x18\x64\x65lete_checkpoint_stream\x18\x04 \x01(\x08\"\x0c\n\nDeleteResp\"\xb5\x02\n\rStatisticsReq\x12\x46\n\x07options\x18\x01 \x01(\x0b\x32\x35.event_store.client.projections.StatisticsReq.Options\x1a\xdb\x01\n\x07Options\x12\x0e\n\x04name\x18\x01 \x01(\tH\x00\x12(\n\x03\x61ll\x18\x02 \x01(\x0b\x32\x19.event_store.client.EmptyH\x00\x12.\n\ttransient\x18\x03 \x01(\x0b\x32\x19.event_store.client.EmptyH\x00\x12/\n\ncontinuous\x18\x04 \x01(\x0b\x32\x19.event_store.client.EmptyH\x00\x12-\n\x08one_time\x18\x05 \x01(\x0b\x32\x19.event_store.client.EmptyH\x00\x42\x06\n\x04mode\"\xb0\x04\n\x0eStatisticsResp\x12G\n\x07\x64\x65tails\x18\x01 \x01(\x0b\x32\x36.event_store.client.projections.StatisticsResp.Details\x1a\xd4\x03\n\x07\x44\x65tails\x12\x1a\n\x12\x63oreProcessingTime\x18\x01 \x01(\x03\x12\x0f\n\x07version\x18\x02 \x01(\x03\x12\r\n\x05\x65poch\x18\x03 \x01(\x03\x12\x15\n\reffectiveName\x18\x04 \x01(\t\x12\x18\n\x10writesInProgress\x18\x05 \x01(\x05\x12\x17\n\x0freadsInProgress\x18\x06 \x01(\x05\x12\x18\n\x10partitionsCached\x18\x07 \x01(\x05\x12\x0e\n\x06status\x18\x08 \x01(\t\x12\x13\n\x0bstateReason\x18\t \x01(\t\x12\x0c\n\x04name\x18\n \x01(\t\x12\x0c\n\x04mode\x18\x0b \x01(\t\x12\x10\n\x08position\x18\x0c \x01(\t\x12\x10\n\x08progress\x18\r \x01(\x02\x12\x16\n\x0elastCheckpoint\x18\x0e \x01(\t\x12#\n\x1b\x65ventsProcessedAfterRestart\x18\x0f \x01(\x03\x12\x18\n\x10\x63heckpointStatus\x18\x10 \x01(\t\x12\x16\n\x0e\x62ufferedEvents\x18\x11 \x01(\x03\x12*\n\"writePendingEventsBeforeCheckpoint\x18\x12 \x01(\x05\x12)\n!writePendingEventsAfterCheckpoint\x18\x13 \x01(\x05\"y\n\x08StateReq\x12\x41\n\x07options\x18\x01 \x01(\x0b\x32\x30.event_store.client.projections.StateReq.Options\x1a*\n\x07Options\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tpartition\x18\x02 \x01(\t\"2\n\tStateResp\x12%\n\x05state\x18\x01 \x01(\x0b\x32\x16.google.protobuf.Value\"{\n\tResultReq\x12\x42\n\x07options\x18\x01 \x01(\x0b\x32\x31.event_store.client.projections.ResultReq.Options\x1a*\n\x07Options\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tpartition\x18\x02 \x01(\t\"4\n\nResultResp\x12&\n\x06result\x18\x01 \x01(\x0b\x32\x16.google.protobuf.Value\"\x80\x01\n\x08ResetReq\x12\x41\n\x07options\x18\x01 \x01(\x0b\x32\x30.event_store.client.projections.ResetReq.Options\x1a\x31\n\x07Options\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x18\n\x10write_checkpoint\x18\x02 \x01(\x08\"\x0b\n\tResetResp\"h\n\tEnableReq\x12\x42\n\x07options\x18\x01 \x01(\x0b\x32\x31.event_store.client.projections.EnableReq.Options\x1a\x17\n\x07Options\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x0c\n\nEnableResp\"\x84\x01\n\nDisableReq\x12\x43\n\x07options\x18\x01 \x01(\x0b\x32\x32.event_store.client.projections.DisableReq.Options\x1a\x31\n\x07Options\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x18\n\x10write_checkpoint\x18\x02 \x01(\x08\"\r\n\x0b\x44isableResp2\xcb\x07\n\x0bProjections\x12_\n\x06\x43reate\x12).event_store.client.projections.CreateReq\x1a*.event_store.client.projections.CreateResp\x12_\n\x06Update\x12).event_store.client.projections.UpdateReq\x1a*.event_store.client.projections.UpdateResp\x12_\n\x06\x44\x65lete\x12).event_store.client.projections.DeleteReq\x1a*.event_store.client.projections.DeleteResp\x12m\n\nStatistics\x12-.event_store.client.projections.StatisticsReq\x1a..event_store.client.projections.StatisticsResp0\x01\x12\x62\n\x07\x44isable\x12*.event_store.client.projections.DisableReq\x1a+.event_store.client.projections.DisableResp\x12_\n\x06\x45nable\x12).event_store.client.projections.EnableReq\x1a*.event_store.client.projections.EnableResp\x12\\\n\x05Reset\x12(.event_store.client.projections.ResetReq\x1a).event_store.client.projections.ResetResp\x12\\\n\x05State\x12(.event_store.client.projections.StateReq\x1a).event_store.client.projections.StateResp\x12_\n\x06Result\x12).event_store.client.projections.ResultReq\x1a*.event_store.client.projections.ResultResp\x12H\n\x10RestartSubsystem\x12\x19.event_store.client.Empty\x1a\x19.event_store.client.EmptyB+\n)com.eventstore.dbclient.proto.projectionsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'projections_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)com.eventstore.dbclient.proto.projections'
  _CREATEREQ._serialized_start=98
  _CREATEREQ._serialized_end=533
  _CREATEREQ_OPTIONS._serialized_start=180
  _CREATEREQ_OPTIONS._serialized_end=533
  _CREATEREQ_OPTIONS_TRANSIENT._serialized_start=419
  _CREATEREQ_OPTIONS_TRANSIENT._serialized_end=444
  _CREATEREQ_OPTIONS_CONTINUOUS._serialized_start=446
  _CREATEREQ_OPTIONS_CONTINUOUS._serialized_end=525
  _CREATERESP._serialized_start=535
  _CREATERESP._serialized_end=547
  _UPDATEREQ._serialized_start=550
  _UPDATEREQ._serialized_end=763
  _UPDATEREQ_OPTIONS._serialized_start=632
  _UPDATEREQ_OPTIONS._serialized_end=763
  _UPDATERESP._serialized_start=765
  _UPDATERESP._serialized_end=777
  _DELETEREQ._serialized_start=780
  _DELETEREQ._serialized_end=979
  _DELETEREQ_OPTIONS._serialized_start=861
  _DELETEREQ_OPTIONS._serialized_end=979
  _DELETERESP._serialized_start=981
  _DELETERESP._serialized_end=993
  _STATISTICSREQ._serialized_start=996
  _STATISTICSREQ._serialized_end=1305
  _STATISTICSREQ_OPTIONS._serialized_start=1086
  _STATISTICSREQ_OPTIONS._serialized_end=1305
  _STATISTICSRESP._serialized_start=1308
  _STATISTICSRESP._serialized_end=1868
  _STATISTICSRESP_DETAILS._serialized_start=1400
  _STATISTICSRESP_DETAILS._serialized_end=1868
  _STATEREQ._serialized_start=1870
  _STATEREQ._serialized_end=1991
  _STATEREQ_OPTIONS._serialized_start=1949
  _STATEREQ_OPTIONS._serialized_end=1991
  _STATERESP._serialized_start=1993
  _STATERESP._serialized_end=2043
  _RESULTREQ._serialized_start=2045
  _RESULTREQ._serialized_end=2168
  _RESULTREQ_OPTIONS._serialized_start=1949
  _RESULTREQ_OPTIONS._serialized_end=1991
  _RESULTRESP._serialized_start=2170
  _RESULTRESP._serialized_end=2222
  _RESETREQ._serialized_start=2225
  _RESETREQ._serialized_end=2353
  _RESETREQ_OPTIONS._serialized_start=2304
  _RESETREQ_OPTIONS._serialized_end=2353
  _RESETRESP._serialized_start=2355
  _RESETRESP._serialized_end=2366
  _ENABLEREQ._serialized_start=2368
  _ENABLEREQ._serialized_end=2472
  _ENABLEREQ_OPTIONS._serialized_start=632
  _ENABLEREQ_OPTIONS._serialized_end=655
  _ENABLERESP._serialized_start=2474
  _ENABLERESP._serialized_end=2486
  _DISABLEREQ._serialized_start=2489
  _DISABLEREQ._serialized_end=2621
  _DISABLEREQ_OPTIONS._serialized_start=2304
  _DISABLEREQ_OPTIONS._serialized_end=2353
  _DISABLERESP._serialized_start=2623
  _DISABLERESP._serialized_end=2636
  _PROJECTIONS._serialized_start=2639
  _PROJECTIONS._serialized_end=3610
# @@protoc_insertion_point(module_scope)
